using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using FTPAttachmentV20;
using System.Web.Configuration;
using enzigma.net.storage;

public partial class Test : System.Web.UI.Page
{
    protected string[] m_arrRequiredParams = new string[] { "FieldName", "FieldValue", "SFUrl", "SFSessionID" };
    protected void Page_Load(object sender, EventArgs e)
    {
		lbError.Text = "";
        if (!String.IsNullOrEmpty(Request.Params["ServerProfile"]))
            txtProfile.Text = Request.Params["ServerProfile"];
    }
	protected void btnSubmit_Click(object sender, EventArgs e)
	{
        string strError = FTPService.CheckRequiredFields(Context, m_arrRequiredParams);
        if (!String.IsNullOrEmpty(strError))
        {
            lbError.Text = strError;
            return;
        }

        WebServiceHeader header = new WebServiceHeader();
        header.SFSessionID = Request["SFSessionID"];
        header.SFUrl = Request["SFUrl"];

        FTPAttachmentsWebService20 ftpAttachmentsServiceV20 = new FTPAttachmentsWebService20();
        ftpAttachmentsServiceV20.WebServiceHeaderValue = header;
        ftpAttachmentsServiceV20.Url = WebConfigurationManager.AppSettings["FTPAttachmentV20.20"];
        HttpFileCollection uplodedFiles = Request.Files;

        if (uplodedFiles == null || uplodedFiles.Count < 1)
        {
            lbError.Text = "No attchments.";
            return;
        }

        FTPAttachmentV20.FTPAttachments attachment = FTPService.CreateFTPAttachmentsV20(Context);
        if (attachment == null)
        {
            lbError.Text = "Unable to create attachments.";
            return;
        }

        attachment.ServerProfile = txtProfile.Text.Trim();
        attachment.IsPublic = chkIsPublic.Checked;
        attachment.Comment = txtComment.Text;

        IProfile profile = null;
        IStorage storage = null;
        string strMessages = string.Empty;
        RegisterResult result = null;
        for (int iIndex = 0; iIndex < uplodedFiles.Count; iIndex++)
        {
            try
            {
                HttpPostedFile uploadedFile = uplodedFiles[iIndex];
                if (uploadedFile == null || String.IsNullOrEmpty(uploadedFile.FileName))
                    continue;

                attachment.FileName = System.IO.Path.GetFileName(uploadedFile.FileName);
                attachment.Size = uploadedFile.ContentLength;
                attachment.Status = FtpAttachmentStatus.Uploading;

                result = ftpAttachmentsServiceV20.RegisterUpload(attachment,null);
                if (result == null)
                {
                    strMessages = "Unable to Register attchment for File: " + attachment.FileName;
                    continue;
                }

                #region enzigma.net.storage Code
                if (result.ServerProfile != null)
                {
                    profile = FTPService.GetProfile(result.ServerProfile);
                    storage = IStorage.CreateInstance(profile);
                }

                if(storage == null)
                {
                    strMessages = "Unable to create Storage object for File: " + attachment.FileName;
                    continue;
                }

                if (storage.Connect())
                {
                    string strRemoteFile = result.FolderPath + result.FileName;
                    String strFilePath = Request.PhysicalApplicationPath + "App_Data\\Temp\\" + uploadedFile.FileName;
                    uploadedFile.SaveAs(strFilePath);
                    if (storage.Upload(strFilePath, strRemoteFile, true))
                    {
                        //Global.LogDebug(String.Format("File successfully uploaded '{0}' to {1} Server. StartTime :{2} EndTime : {3}", m_uploadInfo.FileName, profile.StorageType, m_uploadInfo.StartTime, m_uploadInfo.EndTime));
                        attachment.AttachmentID = result.AttachmentId;
                        attachment.AttachmentVersionId = result.AttachmentVersionId;
                        attachment.Status = FtpAttachmentStatus.Available;
                        AttachResult updateResult = ftpAttachmentsServiceV20.AddAttachment(attachment);
                        if (updateResult.Error == FTPAttachmentErrors.Success)
                            strMessages = String.Format("File : {0} uploaded successfully.", attachment.FileName);
                        else
                            strMessages = "Errors during uploading File : " + attachment.FileName + " " + updateResult.ErrorText;
                    }
                }
            }
            catch (Exception ex)
            {
                if(result != null && !String.IsNullOrEmpty(result.FileName))
                {
                    string strAttachmentId = result.FileName.Split('~')[0];
                    ftpAttachmentsServiceV20.DeleteAttachment(new string[] { strAttachmentId });
                }
                strMessages = "Exception during uploading File : " + attachment.FileName + " " + ex.Message;
            }
            finally
            {
                if (storage != null)
                    storage.Disconnect();
            }
            #endregion
		}

        if (!String.IsNullOrEmpty(strMessages))
            lbError.Text = strMessages;
    }
}
